<?php
/*
Plugin Name: Dentdelion Sarl Chalet Availability
Description: Display Bramble Ski, Haute Montagne and Lagom Chalet Availability easily on your website.
Author: Media Street Ltd
Author URI: https://www.media-street.co.uk
Version: 1.3
*/


/************************/
/** MS Update Checker **/
/***********************/
require 'plugin-update-checker/plugin-update-checker.php';
$myUpdateChecker = Puc_v4_Factory::buildUpdateChecker(
	'https://github.com/mediastreet/dentdelion-availability',
	__FILE__,
	'dentdelion-availability'
);

$myUpdateChecker->setAuthentication('5e933c7b05987340661f628516ee70b06b473272');
// $myUpdateChecker->setBranch('stable-branch-name');


/************************/
/** Create Database    **/
/************************/
function create_plugin_database_table()
{

    global $table_prefix, $wpdb;

    $tblname = 'availability_feed_details';
    $wp_track_table = $tblname;

    #Check to see if the table exists already, if not, then create it

    if($wpdb->get_var( "show tables like '$wp_track_table'" ) != $wp_track_table) 
    {

        $sql = "CREATE TABLE `". $wp_track_table . "` ( ";
        $sql .= "  `id`  int(11)   NOT NULL auto_increment, ";
        $sql .= "  `site_url`  varchar(255)   NOT NULL, ";
        $sql .= "  `feed_username`  varchar(255)   NOT NULL, ";
        $sql .= "  `feed_password`  varchar(255)   NOT NULL, ";
        $sql .= "  `load_jquery`  tinyint(1)   NULL, ";
        $sql .= "  `jquery_version`  varchar(255)   NULL, ";
        $sql .= "  `desktop_show`  int(11)   NOT NULL DEFAULT 3, ";
        $sql .= "  `desktop_scroll`  int(11)  NOT NULL DEFAULT 3, ";
        $sql .= "  `laptop_show`  int(11)  NOT NULL DEFAULT 2, ";
        $sql .= "  `laptop_scroll`  int(11)   NOT NULL DEFAULT 2, ";
        $sql .= "  `tablet_show`  int(11)  NOT NULL DEFAULT 1, ";
        $sql .= "  `tablet_scroll`  int(11)  NOT NULL DEFAULT 1, ";
        $sql .= "  `mobile_show`  int(11)  NOT NULL DEFAULT 1, ";
        $sql .= "  `mobile_scroll`  int(11)  NOT NULL DEFAULT 1, ";
        $sql .= "  PRIMARY KEY `order_id` (`id`) "; 
        $sql .= ") ENGINE=MyISAM DEFAULT CHARSET=latin1 AUTO_INCREMENT=1 ; ";
        require_once( ABSPATH . '/wp-admin/includes/upgrade.php' );
        
        dbDelta($sql);
    }
}

register_activation_hook( __FILE__, 'create_plugin_database_table' );

add_action('admin_menu', 'availability_setup_menu');
 
function availability_setup_menu(){
        add_menu_page( 'Availability Plugin Page', 'Dentdelion Sàrl', 'manage_options', 'availability-plugin-config', 'availability_plugin_init', 'dashicons-calendar-alt' );
}

add_action('wp_enqueue_scripts', 'availability_plugin_scripts');
function availability_plugin_scripts() {
    wp_register_style( 'availability_css', plugins_url('css/chalet-availability.css',__FILE__ ));
    wp_enqueue_style( 'availability_css' );
    wp_enqueue_style( 'slick-css', 'https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.css' );    
}

add_action( 'wp_footer', 'my_footer_scripts' );
function my_footer_scripts(){
    global $wpdb;
    $sql="SELECT * FROM availability_feed_details where site_url = '".site_url()."'";
    $data = $wpdb->get_results($sql, ARRAY_A);
    if($data[0]['load_jquery']==1){ ?>
    <?php if($data[0]['jquery_version']!=''){ ?>
      <script type="text/javascript" src="https://code.jquery.com/<?php echo $data[0]['jquery_version']; ?>"></script>
    <?php }else{ ?>
      <script type="text/javascript" src="<?php echo includes_url(); ?>/js/jquery/jquery.js"></script>
    <?php } ?>        
      <script type="text/javascript" src="<?php echo includes_url(); ?>/js/jquery/jquery-migrate.min.js"></script>
    <?php } ?>
    
    <script type="text/javascript" src="https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.8.1/slick.js"></script>
   
    <script type="text/javascript">
        jQuery(document).ready(function($){

            $('.prices_list').each(function(key, item) {
              var id = $(this).attr('id');
              var sliderIdName = id;
              var sliderId = '#' + sliderIdName;

              $(sliderId).slick({
                slidesToShow: <?php echo $data[0]['desktop_show']; ?>,
                slidesToScroll: <?php echo $data[0]['desktop_scroll']; ?>,              
                infinite: false,                
                nextArrow: $('#next'+sliderIdName),
                prevArrow: $('#prev'+sliderIdName),
                
                responsive: [{
                          breakpoint: 1500,
                          settings: {
                            slidesToShow: <?php echo $data[0]['laptop_show']; ?>,
                            slidesToScroll: <?php echo $data[0]['laptop_scroll']; ?>
                          }
                        },
                        {
                          breakpoint: 1020,
                          settings: {
                            slidesToShow: <?php echo $data[0]['tablet_show']; ?>,
                            slidesToScroll: <?php echo $data[0]['tablet_scroll']; ?>
                          }
                        },
                          {
                          breakpoint: 768,
                          settings: {
                            slidesToShow: <?php echo $data[0]['mobile_show']; ?>,
                            slidesToScroll: <?php echo $data[0]['mobile_scroll']; ?>
                          }
                        }]  
              }); 
              $(sliderId).on('afterChange init', function(event, slick, direction){
                    $('.slick-active:first .row.data .row >  .col-xs-2:first').hover(function(){
                        $(this).addClass('active-left');
                    });
                    $('.slick-active:first .row.data .row >  .col-xs-3:first').hover(function(){
                        $(this).addClass('active-left');
                    });
                    $('.slick-active:last .row.data .row >  .col-xs-2:last').hover(function(){
                        $(this).addClass('active-right');
                    });
                    $('.slick-active:last .row.data .row >  .col-xs-3:last').hover(function(){
                        $(this).addClass('active-right');
                    });
                 });          
            });
        
            $('.prices_list_summer').each(function(key, item) {
              var id = $(this).attr('id');
              var sliderIdName = id;
              var sliderId = '#' + sliderIdName;

              $(sliderId).slick({
                slidesToShow: <?php echo $data[0]['desktop_show']; ?>,
                slidesToScroll: <?php echo $data[0]['desktop_scroll']; ?>,  
                infinite: false,
                nextArrow: $('#next_summer'+sliderIdName),
                prevArrow: $('#prev_summer'+sliderIdName),

                responsive: [{
                          breakpoint: 1500,
                          settings: {
                            slidesToShow: <?php echo $data[0]['laptop_show']; ?>,
                            slidesToScroll: <?php echo $data[0]['laptop_scroll']; ?>
                          }
                        },
                        {
                          breakpoint: 1020,
                          settings: {
                            slidesToShow: <?php echo $data[0]['tablet_show']; ?>,
                            slidesToScroll: <?php echo $data[0]['tablet_scroll']; ?>
                          }
                        },
                          {
                          breakpoint: 768,
                          settings: {
                            slidesToShow: <?php echo $data[0]['mobile_show']; ?>,
                            slidesToScroll: <?php echo $data[0]['mobile_scroll']; ?>
                          }
                        }                 
                        
                        
                        ]  
                  });
                  $(sliderId).on('afterChange init', function(event, slick, direction){
                    $('.slick-active:first .row.data .row >  .col-xs-2:first').hover(function(){
                        $(this).addClass('active-left');
                    });
                    $('.slick-active:first .row.data .row >  .col-xs-3:first').hover(function(){
                        $(this).addClass('active-left');
                    });
                    $('.slick-active:last .row.data .row >  .col-xs-2:last').hover(function(){
                        $(this).addClass('active-right');
                    });
                    $('.slick-active:last .row.data .row >  .col-xs-3:last').hover(function(){
                        $(this).addClass('active-right');
                    });
                 });               
            });
            
        });
        </script>
        <?php
}
 
function availability_plugin_init(){

    global $wpdb;
        echo "<h1>Dentdelion S&agrave;rl Availability Plugin</h1>";
        $site_url = site_url();

        if(isset($_POST['submit']) && $_POST['submit']!=''){
            if( ($_POST['username']!='' && $_POST['password']!='') ){
              
                    $wpdb->query("DELETE FROM availability_feed_details WHERE site_url = '".$site_url."' AND feed_username='".$_POST['username']."'");
                    $res = $wpdb->query("INSERT INTO availability_feed_details 
                        SET site_url = '".$site_url."',
                        feed_username = '".$_POST['username']."',
                        feed_password = '".$_POST['password']."'
                        on duplicate key update
                        feed_username = '".$_POST['username']."',
                        feed_password = '".$_POST['password']."'
                        ");               

                if($res === false){
                  echo '<p class="error">Error. Please try again.</p>';
                }else{
                  echo '<p class="success">Data successfully saved.</p>';
                }
            }else{
                echo '<p class="error">Error. Please fill up the fields.</p>';
            }
        }

        if(isset($_POST['submit_js']) && $_POST['submit_js']!=''){
            $js = isset($_POST['load_jquery']) ? 1 : 0;
            $js_version = $_POST['jquery_version']!='' ? $_POST['jquery_version'] : '';
            $desktop_show = $_POST['desktop_show']!='' ? $_POST['desktop_show'] : 3;
            $desktop_scroll = $_POST['desktop_scroll']!='' ? $_POST['desktop_scroll'] : 3;
            $laptop_show = $_POST['laptop_show']!='' ? $_POST['laptop_show'] : 2;
            $laptop_scroll = $_POST['laptop_scroll']!='' ? $_POST['laptop_scroll'] : 2;
            $tablet_show = $_POST['tablet_show']!='' ? $_POST['tablet_show'] : 1;
            $tablet_scroll = $_POST['tablet_scroll']!='' ? $_POST['tablet_scroll'] : 1;
            $mobile_show = $_POST['mobile_show']!='' ? $_POST['mobile_show'] : 1;
            $mobile_scroll = $_POST['mobile_scroll']!='' ? $_POST['mobile_scroll'] : 1;
            
            $res_js = $wpdb->query( "UPDATE availability_feed_details SET load_jquery=".$js.", jquery_version='".esc_sql($js_version)."', desktop_show=".$desktop_show.", desktop_scroll=".$desktop_scroll.", laptop_show=".$laptop_show.", laptop_scroll=".$laptop_scroll.", tablet_show=".$tablet_show.", tablet_scroll=".$tablet_scroll.", mobile_show=".$mobile_show.", mobile_scroll=".$mobile_scroll." WHERE site_url = '".$site_url."' " );
            
            if($res_js === false){
              echo '<p class="error">Error. Please try again.</p>';                
            }else{              
              echo '<p class="success">Data successfully saved.</p>';
            }               
        }        
        ?>
        <?php 

        $feed_username=$feed_password=$load_jquery=$jquery_version=$desktop_show=$desktop_scroll=$laptop_show=$laptop_scroll=$tablet_show=$tablet_scroll=$mobile_show=$mobile_scroll='';
         $sql="SELECT * FROM availability_feed_details where site_url = '".$site_url."'";
         $data = $wpdb->get_results($sql, ARRAY_A);
         if(count($data)){
            $feed_username = ($data[0]['feed_username']!='') ? $data[0]['feed_username'] : '';
             $feed_password = ($data[0]['feed_password']!='') ? $data[0]['feed_password'] : '';
             $load_jquery = ($data[0]['load_jquery']!='') ? $data[0]['load_jquery'] : 0;
             $jquery_version = ($load_jquery==1 && $data[0]['jquery_version']!='') ? $data[0]['jquery_version'] : '';
             $desktop_show = ($data[0]['desktop_show']!='') ? $data[0]['desktop_show'] : '';
             $desktop_scroll = ($data[0]['desktop_scroll']!='') ? $data[0]['desktop_scroll'] : '';
             $laptop_show = ($data[0]['laptop_show']!='') ? $data[0]['laptop_show'] : '';
             $laptop_scroll = ($data[0]['laptop_scroll']!='') ? $data[0]['laptop_scroll'] : '';
             $tablet_show = ($data[0]['tablet_show']!='') ? $data[0]['tablet_show'] : '';
             $tablet_scroll = ($data[0]['tablet_scroll']!='') ? $data[0]['tablet_scroll'] : '';
             $mobile_show = ($data[0]['mobile_show']!='') ? $data[0]['mobile_show'] : '';
             $mobile_scroll = ($data[0]['mobile_scroll']!='') ? $data[0]['mobile_scroll'] : '';
         } 
        ?>
        
        <div class="dent_loginbox">
        <p>Please login first / enter your agent API details. If you don't know your details please contact <a href="mailto:barry@brambleski.com">barry@brambleski.com</a>.</p>
        <form method="post" action="">
          Username: <input name="username" type="text" value="<?php echo $feed_username; ?>" /><br />
          Password: <input name="password" type="password" value="<?php echo $feed_password; ?>" /><br />
          <input class="dent_btn" type="submit" name="submit" value="Go" />
        </form>
        </div>

        <div class="dent_loginbox">
            <form method="post" action="">
                Enable JQuery <input type="checkbox" name="load_jquery" value="1" <?php if($load_jquery==1){ ?>checked<?php } ?> /> <br>
                JQuery Version(optional) <input type="text" name="jquery_version" value="<?php echo $jquery_version; ?>" placeholder="jquery-3.4.1.min.js" />
                <h2>Desktop Screens</h2>
                Slides to Show <input type="text" name="desktop_show" value="<?php echo $desktop_show; ?>"  />
                Slides to Scroll <input type="text" name="desktop_scroll" value="<?php echo $desktop_scroll; ?>"  />
                <h2>Laptops (1020px - 1500px)</h2>
                Slides to Show <input type="text" name="laptop_show" value="<?php echo $laptop_show; ?>"  />
                Slides to Scroll <input type="text" name="laptop_scroll" value="<?php echo $laptop_scroll; ?>"  />
                <h2>Tablets(768px - 1020px)</h2>
                Slides to Show <input type="text" name="tablet_show" value="<?php echo $tablet_show; ?>"  />
                Slides to Scroll <input type="text" name="tablet_scroll" value="<?php echo $tablet_scroll; ?>"  />
                <h2>Mobiles(768px or smaller)</h2>
                Slides to Show <input type="text" name="mobile_show" value="<?php echo $mobile_show; ?>"  />
                Slides to Scroll <input type="text" name="mobile_scroll" value="<?php echo $mobile_scroll; ?>"  />
                <br />
                <input class="dent_btn" type="submit" name="submit_js" value="Save" />
            </form>
        </div>

        <div>         
        <h2>Instructions</h2>
          <p>Thank you for installing the latest version of our availability plug-in. Allowing our reseller agencies to easily list our chalets on their own Wordpress websites without needing to know any coding languages.</p>
          <p><strong>How to use the shortcode:</strong></p>
          <ul class="dent_list">
            <li>[availability] => To show availability for all properties with all service levels</li>
            <li>[availability service_level="Catered"] => To show availability for a single service level e.g. "Catered"</li>
            <li>[availability id="248"] => To show availability for property ID 248</li>
            <li>[availability service_level="Catered" id="248"] => To show availability for property ID "248" for "Catered" service level</li>
            <li>[availability service_level="Catered" id="248" main_title="false"] => To show availability for property ID "248" for "Catered" service level without main title </li>
            <li>[availability service_level="Catered" id="248" chalet_title="false"] => To show availability for property ID "248" for "Catered" service level without chalet title </li>
            <li>[availability id="248" display="dates_vertical"] => To show availability in a different layout having vertical dates and service levels horizontally  </li>
            <li>[availability service_level="Catered" id="248" display="dates_extended" tooltip="false"] => To show availability for property ID "248" for a specific service level without tooltips </li>
          </ul>
          <p>To view examples of all displays you can visit our <a href="https://dentdelion-plugin.com/" target="_blank">demo website</a>.</p>
        <h2>Service Level Details</h2>
          <p>If you're wanting to display prices for any certain service level you can use the following in your shortcode.</p>
          <ul class="dent_list">
            <li>Catered</li>
            <li>Self-Catered</li>
            <li>Short-stay catered</li>
            <li>Short-stay self-catered</li>
            <li>Bed and breakfast</li>
            <li>Short-stay bed and breakfast</li>
            <li>Accommodation Only</li>
            <li>Summer</li>
          </ul>
      
        <?php

        if($feed_username!='' && $feed_password!=''){ ?>
        <h2>Property IDs</h2>

        <p>For property IDs, please refer below:
            <?php
            $properties = get_BS_properties($feed_username, $feed_password);
            ?>
            <ul class="col-3 dent_list">
            <?php
            foreach($properties as $prop){
            ?>
                <li><?php echo $prop->PropertyId; ?> => <?php echo $prop->Name; ?></li>
            <?php
            }
            ?>
            </ul>
            <?php
            
        ?>
        </p>
        <?php } ?>
        </div>
        
        <style>
       .dent_btn {
      	background: rgba(14,94,88,1.0);
      	color: #FFF;
      	padding: 5px 20px;
      	text-transform: uppercase;
      	margin-top: 20px;
      	border: none;
      }
     .dent_loginbox {
    	background: #FFF;
    	box-sizing: border-box;
    	padding: 30px;
    }

    .dent_loginbox {}
    .dent_list{}
    .dent_list li {
    	list-style: disc;
    	list-style-position: inside;
    }
          
    ul.col-3 {
      column-count: 3;
      column-gap: 10px;
    }
        
    </style>

    <?php
  }

function get_BS_properties($username, $password){
    $url = 'https://www.brambleski.com/feedv5/properties.php';
    $fields = array(
        'username'=>$username,
        'password'=>$password
    );

    $fields_string = '';
    foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
    rtrim($fields_string,'&');

    $ch = curl_init();

    curl_setopt($ch,CURLOPT_URL,$url);
    curl_setopt($ch,CURLOPT_POST,count($fields));
    curl_setopt($ch,CURLOPT_POSTFIELDS,$fields_string);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
    curl_setopt($ch, CURLOPT_ENCODING, '');

    $result = curl_exec($ch);

    curl_close($ch);

    $properties = new SimpleXMLElement($result);
    return $properties;
}

add_shortcode("availability", "get_chalet_availability");

function get_chalet_availability($atts){
    global $wpdb;
    $result = '';
    ob_start();
   if(!is_admin()){

    $a = shortcode_atts( 
        array(
            'id'   => '-1',
            'service_level'   => '',
            'display' => '',
            'main_title' => 'true',
            'chalet_title' => 'true',
            'tooltip' => 'true'
        ), 
        $atts
    );
    
    $chalet_id = $a['id'];
    $sl = $a['service_level'];
    $display = $a['display'];
    $main_title = $a['main_title'];
    $chalet_title = $a['chalet_title'];
    $tooltip = $a['tooltip'];

    $sql="SELECT feed_username,feed_password,load_jquery FROM availability_feed_details where site_url = '".site_url()."'";
    $data = $wpdb->get_results($sql, ARRAY_A);

    if( count($data) ){
        //Curl to get data from brambleski
        $url = 'https://www.brambleski.com/feedv5/availability.php';
        $fields = array(
                    'username'=>$data[0]['feed_username'],
                    'password'=>$data[0]['feed_password'],
                    'properties'=>$chalet_id,
                    'service_level'=>$sl,
                    'display'=>$display,
                    'main_title'=>$main_title,
                    'chalet_title'=>$chalet_title,
                    'tooltip'=>$tooltip,
                    'source'=>'av_plugin',
                    'load_jquery'=>$data[0]['load_jquery']
                );

        $fields_string = '';
        foreach($fields as $key=>$value) { $fields_string .= $key.'='.$value.'&'; }
        rtrim($fields_string,'&');

        $ch = curl_init();

        curl_setopt($ch,CURLOPT_URL,$url);
        curl_setopt($ch,CURLOPT_POST,count($fields));
        curl_setopt($ch,CURLOPT_POSTFIELDS,$fields_string);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_ENCODING, '');

        $result = curl_exec($ch);

        curl_close($ch);
    } else {
        echo 'Please enter agent details in plugin config page!';
    }

   }
    return $result;   
}

register_deactivation_hook( __FILE__, 'my_plugin_remove_database' );
function my_plugin_remove_database() {
     global $wpdb;
     $table_name = 'availability_feed_details';
     $sql = "DROP TABLE IF EXISTS $table_name";
     $wpdb->query($sql);
     delete_option("my_plugin_db_version");
}   
?>